@@ -1,13 +1,13 @@
 ;;; develock.el --- additional font-lock keywords for the developers
 
-;; Copyright (C) 2001, 2002, 2003, 2005, 2006 Katsumi Yamaoka
+;; Copyright (C) 2001, 2002, 2003, 2005, 2006, 2007 Katsumi Yamaoka
 
 ;; Author: Katsumi Yamaoka  <yamaoka@jpl.org>
 ;;         Jun'ichi Shiono  <jun@fsas.fujitsu.com>
 ;;         Yasutaka SHINDOH <ring-pub@fan.gr.jp>
 ;;         Oscar Bonilla    <ob@bitmover.com>
 ;; Created: 2001/06/28
-;; Revised: 2006/10/02
+;; Revised: 2007/06/26
 ;; Keywords: font-lock emacs-lisp change-log texinfo c java perl html
 ;;           tcl ruby mail news
 
@@ -213,7 +213,7 @@
 
 ;;; Code:
 
-(defconst develock-version "0.30"
+(defconst develock-version "0.34"
   "Version number for this version of Develock.")
 
 (require 'advice)
@@ -277,28 +277,31 @@ minor mode strings as shown below:
     '(setcdr (assq 'font-lock-mode minor-mode-alist)
 	     (list (cons 'develock-mode develock-mode-strings)))))
 
-(defface develock-whitespace-face-1
+(defface develock-whitespace-1
   '((t (:background "Red")))
   "Develock face used to highlight whitespace."
   :group 'develock
   :group 'font-lock-highlighting-faces
   :group 'font-lock-faces)
+(put 'develock-whitespace-face-1 'face-alias 'develock-whitespace-1)
 
-(defface develock-whitespace-face-2
+(defface develock-whitespace-2
   '((t (:background "Orange")))
   "Develock face used to highlight whitespace."
   :group 'develock
   :group 'font-lock-highlighting-faces
   :group 'font-lock-faces)
+(put 'develock-whitespace-face-2 'face-alias 'develock-whitespace-2)
 
-(defface develock-whitespace-face-3
+(defface develock-whitespace-3
   '((t (:background "Yellow")))
   "Develock face used to highlight whitespace."
   :group 'develock
   :group 'font-lock-highlighting-faces
   :group 'font-lock-faces)
+(put 'develock-whitespace-face-3 'face-alias 'develock-whitespace-3)
 
-(defface develock-long-line-face-1
+(defface develock-long-line-1
   '((((background dark))
      (:foreground "Orange"))
     (t
@@ -307,22 +310,26 @@ minor mode strings as shown below:
   :group 'develock
   :group 'font-lock-highlighting-faces
   :group 'font-lock-faces)
+(put 'develock-long-line-face-1 'face-alias 'develock-long-line-1)
 
-(defface develock-long-line-face-2
+(defface develock-long-line-2
   '((t (:foreground "Red" :background "Yellow")))
   "Develock face used to highlight long lines."
   :group 'develock
   :group 'font-lock-highlighting-faces
   :group 'font-lock-faces)
+(put 'develock-long-line-2-face 'face-alias 'develock-long-line-2)
 
-(defface develock-lonely-parentheses-face
+(defface develock-lonely-parentheses
   '((t (:foreground "Blue" :background "PaleTurquoise")))
   "Develock face used to highlight lonely parentheses."
   :group 'develock
   :group 'font-lock-highlighting-faces
   :group 'font-lock-faces)
+(put 'develock-lonely-parentheses-face
+     'face-alias 'develock-lonely-parentheses)
 
-(defface develock-bad-manner-face
+(defface develock-bad-manner
   '((((background dark))
      (:foreground "Black" :background "Yellow"))
     (t
@@ -332,8 +339,9 @@ Those might violate the manners of mail messages or news articles."
   :group 'develock
   :group 'font-lock-highlighting-faces
   :group 'font-lock-faces)
+(put 'develock-bad-manner-face 'face-alias 'develock-bad-manner)
 
-(defface develock-upper-case-tag-face
+(defface develock-upper-case-tag
   '((((background dark))
      (:foreground "Black" :background "PowderBlue"))
     (t
@@ -342,8 +350,9 @@ Those might violate the manners of mail messages or news articles."
   :group 'develock
   :group 'font-lock-highlighting-faces
   :group 'font-lock-faces)
+(put 'develock-upper-case-tag-face 'face-alias 'develock-upper-case-tag)
 
-(defface develock-upper-case-attribute-face
+(defface develock-upper-case-attribute
   '((((background dark))
      (:foreground "Black" :background "Wheat"))
     (t
@@ -352,14 +361,18 @@ Those might violate the manners of mail messages or news articles."
   :group 'develock
   :group 'font-lock-highlighting-faces
   :group 'font-lock-faces)
+(put 'develock-upper-case-attribute-face
+     'face-alias 'develock-upper-case-attribute)
 
-(defface develock-reachable-mail-address-face
+(defface develock-reachable-mail-address
   '((t (:foreground "DarkGreen" :background "LemonChiffon")))
   "Develock face used to highlight reachable E-mail addresses.
 That would be defenseless to spammers."
   :group 'develock
   :group 'font-lock-highlighting-faces
   :group 'font-lock-faces)
+(put 'develock-reachable-mail-address-face
+     'face-alias 'develock-reachable-mail-address)
 
 (defcustom develock-auto-enable t
   "If non-nil, turn Develock mode on when font-lock is turned on."
@@ -792,40 +805,40 @@ Each element should be triple symbols of the following form:
 (defcustom develock-lisp-font-lock-keywords
   '(;; a long line
     (develock-find-long-lines
-     (1 'develock-long-line-face-1 t)
-     (2 'develock-long-line-face-2 t))
+     (1 'develock-long-line-1 t)
+     (2 'develock-long-line-2 t))
     ;; long spaces
     (develock-find-tab-or-long-space
-     (1 'develock-whitespace-face-2)
-     (2 'develock-whitespace-face-3 nil t))
+     (1 'develock-whitespace-2)
+     (2 'develock-whitespace-3 nil t))
     ;; trailing whitespace
     ("[^\t\n ]\\([\t ]+\\)$"
-     (1 'develock-whitespace-face-1 t))
+     (1 'develock-whitespace-1 t))
     ;; spaces before tabs
     ("\\( +\\)\\(\t+\\)"
-     (1 'develock-whitespace-face-1 t)
-     (2 'develock-whitespace-face-2 t))
+     (1 'develock-whitespace-1 t)
+     (2 'develock-whitespace-2 t))
     ;; tab space tab
     ("\\(\t\\) \t"
-     (1 'develock-whitespace-face-2 append))
+     (1 'develock-whitespace-2 append))
     ;; only tabs or spaces in the line
     ("^[\t ]+$"
-     (0 'develock-whitespace-face-2 append))
+     (0 'develock-whitespace-2 append))
     ;; lonely left parentheses or brackets without a comment
     ("^[\t ]*\\(['`]?[\t ([]*[([]\\)[\t ]*$"
-     1 'develock-lonely-parentheses-face)
+     1 'develock-lonely-parentheses)
     ;; lonely right parentheses or brackets
     ("^[\t ]*\\([]\t )]*[])]\\)\\([\t ;]+\\|[\t ]*$\\)"
-     1 'develock-lonely-parentheses-face)
+     1 'develock-lonely-parentheses)
     ;; whitespace after a left parenthesis
     ("(\\([\t ]+\\)[^\n;]"
-     1 'develock-whitespace-face-2)
+     1 'develock-whitespace-2)
     ;; whitespace before a right parenthesis
     ("([^\n]\\([\t ]+\\))"
-     1 'develock-whitespace-face-2)
+     1 'develock-whitespace-2)
     ;; reachable E-mail addresses
     ("<?[-+.0-9A-Z_a-z]+@[-0-9A-Z_a-z]+\\(\\.[-0-9A-Z_a-z]+\\)+>?"
-     (0 'develock-reachable-mail-address-face t)))
+     (0 'develock-reachable-mail-address t)))
   "Extraordinary level highlighting for the Lisp modes."
   :type develock-keywords-custom-type
   :set 'develock-keywords-custom-set
@@ -835,43 +848,65 @@ Each element should be triple symbols of the following form:
 (defcustom develock-change-log-font-lock-keywords
   '(;; a long line
     (develock-find-long-lines
-     (1 'develock-long-line-face-1 append)
-     (2 'develock-long-line-face-2 append))
-    ;; tabs or 3 or more spaces in the entry line
-    ("\t[\t ]*\\|   +"
-     (0 (if (memq (char-after (develock-point-at-bol)) '(?1 ?2))
-	    'develock-whitespace-face-2)
-	append))
-    ;; a leading tab in the entry line
-    ("^\\(\t\\)[12][0-9][0-9][0-9]-[01][0-9]-[0-3][0-9]  "
-     (1 'develock-whitespace-face-2))
+     (1 'develock-long-line-1 append)
+     (2 'develock-long-line-2 append))
+    ;; an ugly entry line
+    ("^\\( +\\|\t[\t ]*\\)?\\(?:[12][0-9][0-9][0-9]-[01][0-9]-[0-3][0-9]\
+\\(?:\\(?: \\|\\(  +\\|\t[\t ]*\\)\\)[012][0-9]:[0-5][0-9]:[0-5][0-9]\\)?\
+\\|\\(?:Sun\\|Mon\\|Tue\\|Wed\\|Thu\\|Fri\\|Sat\\)\
+\\(?: \\|\\(  +\\|\t[\t ]*\\)\\)\
+\\(?:Jan\\|Feb\\|Mar\\|Apr\\|May\\|Jun\\|Jul\\|Aug\\|Sep\\|Oct\\|Nov\\|Dec\\)\
+\\(?: \\|\\(  +\\|\t[\t ]*\\)\\)[ 0-3][0-9]\
+\\(?: \\|\\(  +\\|\t[\t ]*\\)\\)[012][0-9]:[0-5][0-9]:[0-5][0-9]\
+\\(?: \\|\\(  +\\|\t[\t ]*\\)\\)[12][0-9][0-9][0-9]\\)\
+\\(?:  \\|\\( \\|   +\\|\t[\t ]*\\)\\)[^\t <>]+\
+\\(?:\\(?: \\|\\(  +\\|\t[\t ]*\\)\\)[^\t <>]+\\)?\
+\\(?:\\(?: \\|\\(  +\\|\t[\t ]*\\)\\)[^\t <>]+\\)?\
+\\(\\(?:[\t ]+[^\t <>]+\\)*\\)\
+\\(?:\\(?:  \\|\\( \\|   +\\|\t[\t ]*\\)\\)<\\|\\(<\\)\\)[^<>]+>\
+\\(?:\\(?:  \\|\\( \\|   +\\|\t[\t ]*\\)\\)\(\\|\\([^\n ].*\\)\\)?"
+     (1 'develock-whitespace-1 nil t)
+     (2 'develock-whitespace-1 t t)
+     (3 'develock-whitespace-1 t t)
+     (4 'develock-whitespace-1 t t)
+     (5 'develock-whitespace-1 t t)
+     (6 'develock-whitespace-1 t t)
+     (7 'develock-whitespace-1 t t)
+     (8 'develock-whitespace-2 t t)
+     (9 'develock-whitespace-2 t t)
+     (10 'develock-whitespace-3 t t)
+     (11 'develock-whitespace-1 t t)
+     (12 'develock-whitespace-1 t t)
+     (13 'develock-whitespace-1 t t)
+     (14 'develock-whitespace-1 t t))
     ;; leading spaces
     ("^\\( +\\)[^\t\n]"
-     (1 'develock-whitespace-face-3))
+     (1 'develock-whitespace-3))
     ;; leading 2 or more tabs
     ("^\\([\t ][\t ]+\\)[^\t\n]"
-     (1 'develock-whitespace-face-2))
+     (1 'develock-whitespace-2))
     ;; trailing whitespace
     ("[^\t\n ]\\([\t ]+\\)$"
-     (1 'develock-whitespace-face-1 t))
+     (1 'develock-whitespace-1 t))
     ;; tabs or 2 or more spaces in the log line
     ("[^\t\n ]\\(\t[\t ]*\\|  +\\)[^\t ]"
      (1 (if (and (memq (char-after (develock-point-at-bol)) '(?\t ?\ ))
 		 (not (string-equal ".  "
 				    (buffer-substring (1- (match-beginning 1))
 						      (match-end 1)))))
-	    'develock-whitespace-face-2)
+	    'develock-whitespace-2)
 	prepend))
     ;; spaces before tabs
-    ("\\( +\\)\\(\t+\\)"
-     (1 'develock-whitespace-face-1 t)
-     (2 'develock-whitespace-face-2 append))
+    ("\\( +\\)\\(\t+\\)\\([\t ]*\\)"
+     (1 'develock-whitespace-1 t)
+     (2 'develock-whitespace-2 append)
+     (3 'develock-whitespace-2 append t))
     ;; only tabs or spaces in the line
     ("^[\t ]+$"
-     (0 'develock-whitespace-face-2 append))
+     (0 'develock-whitespace-2 append))
     ;; whitespace between a file name and a colon
     ("^\t\\* [^\t\n ]+\\( (.+)\\)?\\([\t ]+\\):"
-     (2 'develock-whitespace-face-1 t)))
+     (2 'develock-whitespace-1 t)))
   "Extraordinary level highlighting for the Change Log mode."
   :type develock-keywords-custom-type
   :set 'develock-keywords-custom-set
@@ -881,21 +916,24 @@ Each element should be triple symbols of the following form:
 (defcustom develock-texinfo-font-lock-keywords
   '(;; a long line
     (develock-find-long-lines
-     (1 'develock-long-line-face-1 t)
-     (2 'develock-long-line-face-2 t))
+     (1 'develock-long-line-1 t)
+     (2 'develock-long-line-2 t))
     ;; trailing whitespace
     ("[^\t\n ]\\([\t ]+\\)$"
-     (1 'develock-whitespace-face-1 t))
+     (1 'develock-whitespace-1 t))
     ;; spaces before tabs
     ("\\( +\\)\\(\t+\\)"
-     (1 'develock-whitespace-face-1 t)
-     (2 'develock-whitespace-face-2 t))
+     (1 'develock-whitespace-1 t)
+     (2 'develock-whitespace-2 t))
     ;; tab space tab
     ("\\(\t\\) \t"
-     (1 'develock-whitespace-face-2 append))
+     (1 'develock-whitespace-2 append))
     ;; only tabs or spaces in the line
     ("^[\t ]+$"
-     (0 'develock-whitespace-face-2 append)))
+     (0 'develock-whitespace-2 append))
+    ;; tabs
+    ("\t+"
+     (0 'develock-whitespace-1 append)))
   "Extraordinary level highlighting for the TeXinfo mode."
   :type develock-keywords-custom-type
   :set 'develock-keywords-custom-set
@@ -905,28 +943,28 @@ Each element should be triple symbols of the following form:
 (defcustom develock-c-font-lock-keywords
   '(;; a long line
     (develock-find-long-lines
-     (1 'develock-long-line-face-1 t)
-     (2 'develock-long-line-face-2 t))
+     (1 'develock-long-line-1 t)
+     (2 'develock-long-line-2 t))
     ;; long spaces
     (develock-find-tab-or-long-space
-     (1 'develock-whitespace-face-2)
-     (2 'develock-whitespace-face-3 nil t))
+     (1 'develock-whitespace-2)
+     (2 'develock-whitespace-3 nil t))
     ;; trailing whitespace
     ("[^\t\n ]\\([\t ]+\\)$"
-     (1 'develock-whitespace-face-1 t))
+     (1 'develock-whitespace-1 t))
     ;; spaces before tabs
     ("\\( +\\)\\(\t+\\)"
-     (1 'develock-whitespace-face-1 t)
-     (2 'develock-whitespace-face-2 t))
+     (1 'develock-whitespace-1 t)
+     (2 'develock-whitespace-2 t))
     ;; tab space tab
     ("\\(\t\\) \t"
-     (1 'develock-whitespace-face-2 append))
+     (1 'develock-whitespace-2 append))
     ;; only tabs or spaces in the line
     ("^[\t ]+$"
-     (0 'develock-whitespace-face-2 append))
+     (0 'develock-whitespace-2 append))
     ;; reachable E-mail addresses
     ("<?[-+.0-9A-Z_a-z]+@[-0-9A-Z_a-z]+\\(\\.[-0-9A-Z_a-z]+\\)+>?"
-     (0 'develock-reachable-mail-address-face t)))
+     (0 'develock-reachable-mail-address t)))
   "Extraordinary level highlighting for the C modes."
   :type develock-keywords-custom-type
   :set 'develock-keywords-custom-set
@@ -936,28 +974,28 @@ Each element should be triple symbols of the following form:
 (defcustom develock-java-font-lock-keywords
   '(;; a long line
     (develock-find-long-lines
-     (1 'develock-long-line-face-1 t)
-     (2 'develock-long-line-face-2 t))
+     (1 'develock-long-line-1 t)
+     (2 'develock-long-line-2 t))
     ;; long spaces
     (develock-find-tab-or-long-space
-     (1 'develock-whitespace-face-2)
-     (2 'develock-whitespace-face-3 nil t))
+     (1 'develock-whitespace-2)
+     (2 'develock-whitespace-3 nil t))
     ;; trailing whitespace
     ("[^\t\n ]\\([\t ]+\\)$"
-     (1 'develock-whitespace-face-1 t))
+     (1 'develock-whitespace-1 t))
     ;; spaces before tabs
     ("\\( +\\)\\(\t+\\)"
-     (1 'develock-whitespace-face-1 t)
-     (2 'develock-whitespace-face-2 t))
+     (1 'develock-whitespace-1 t)
+     (2 'develock-whitespace-2 t))
     ;; tab space tab
     ("\\(\t\\) \t"
-     (1 'develock-whitespace-face-2 append))
+     (1 'develock-whitespace-2 append))
     ;; only tabs or spaces in the line
     ("^[\t ]+$"
-     (0 'develock-whitespace-face-2 append))
+     (0 'develock-whitespace-2 append))
     ;; reachable E-mail addresses
     ("<?[-+.0-9A-Z_a-z]+@[-0-9A-Z_a-z]+\\(\\.[-0-9A-Z_a-z]+\\)+>?"
-     (0 'develock-reachable-mail-address-face t)))
+     (0 'develock-reachable-mail-address t)))
   "Extraordinary level highlighting for the Java mode."
   :type develock-keywords-custom-type
   :set 'develock-keywords-custom-set
@@ -967,35 +1005,35 @@ Each element should be triple symbols of the following form:
 (defcustom develock-html-font-lock-keywords
   '(;; a long line
     (develock-find-long-lines
-     (1 'develock-long-line-face-1 t)
-     (2 'develock-long-line-face-2 t))
+     (1 'develock-long-line-1 t)
+     (2 'develock-long-line-2 t))
     ;; long spaces
     (develock-find-tab-or-long-space
-     (1 'develock-whitespace-face-2)
-     (2 'develock-whitespace-face-3 nil t))
+     (1 'develock-whitespace-2)
+     (2 'develock-whitespace-3 nil t))
     ;; trailing whitespace
     ("[^\t\n ]\\([\t ]+\\)$"
-     (1 'develock-whitespace-face-1 t))
+     (1 'develock-whitespace-1 t))
     ;; spaces before tabs
     ("\\( +\\)\\(\t+\\)"
-     (1 'develock-whitespace-face-1 t)
-     (2 'develock-whitespace-face-2 t))
+     (1 'develock-whitespace-1 t)
+     (2 'develock-whitespace-2 t))
     ;; tab space tab
     ("\\(\t\\) \t"
-     (1 'develock-whitespace-face-2 append))
+     (1 'develock-whitespace-2 append))
     ;; only tabs or spaces in the line
     ("^[\t ]+$"
-     (0 'develock-whitespace-face-2 append))
+     (0 'develock-whitespace-2 append))
     ;; using upper case tag
     ((lambda (limit)
        (let (case-fold-search)
 	 (re-search-forward "</?\\([A-Z]+\\)" limit t)))
-     (1 'develock-upper-case-tag-face t))
+     (1 'develock-upper-case-tag t))
     ;; using upper case attribute
     ((lambda (limit)
        (let (case-fold-search)
 	 (re-search-forward "<[a-zA-Z]+[\t ]+\\([A-Z]+\\)[\t ]*=" limit t)))
-     (1 'develock-upper-case-attribute-face t)))
+     (1 'develock-upper-case-attribute t)))
   "Extraordinary level highlighting for the HTML mode."
   :type develock-keywords-custom-type
   :set 'develock-keywords-custom-set
@@ -1005,28 +1043,28 @@ Each element should be triple symbols of the following form:
 (defcustom develock-cperl-font-lock-keywords
   '(;; a long line
     (develock-find-long-lines
-     (1 'develock-long-line-face-1 t)
-     (2 'develock-long-line-face-2 t))
+     (1 'develock-long-line-1 t)
+     (2 'develock-long-line-2 t))
     ;; long spaces
     (develock-find-tab-or-long-space
-     (1 'develock-whitespace-face-2)
-     (2 'develock-whitespace-face-3 nil t))
+     (1 'develock-whitespace-2)
+     (2 'develock-whitespace-3 nil t))
     ;; trailing whitespace
     ("[^\t\n ]\\([\t ]+\\)$"
-     (1 'develock-whitespace-face-1 t))
+     (1 'develock-whitespace-1 t))
     ;; spaces before tabs
     ("\\( +\\)\\(\t+\\)"
-     (1 'develock-whitespace-face-1 t)
-     (2 'develock-whitespace-face-2 t))
+     (1 'develock-whitespace-1 t)
+     (2 'develock-whitespace-2 t))
     ;; tab space tab
     ("\\(\t\\) \t"
-     (1 'develock-whitespace-face-2 append))
+     (1 'develock-whitespace-2 append))
     ;; only tabs or spaces in the line
     ("^[\t ]+$"
-     (0 'develock-whitespace-face-2 append))
+     (0 'develock-whitespace-2 append))
     ;; reachable E-mail addresses
     ("<?[-+.0-9A-Z_a-z]+@[-0-9A-Z_a-z]+\\(\\.[-0-9A-Z_a-z]+\\)+>?"
-     (0 'develock-reachable-mail-address-face t)))
+     (0 'develock-reachable-mail-address t)))
   "Extraordinary level highlighting for the CPerl mode."
   :type develock-keywords-custom-type
   :set 'develock-keywords-custom-set
@@ -1036,28 +1074,28 @@ Each element should be triple symbols of the following form:
 (defcustom develock-perl-font-lock-keywords
   '(;; a long line
     (develock-find-long-lines
-     (1 'develock-long-line-face-1 t)
-     (2 'develock-long-line-face-2 t))
+     (1 'develock-long-line-1 t)
+     (2 'develock-long-line-2 t))
     ;; long spaces
     (develock-find-tab-or-long-space
-     (1 'develock-whitespace-face-2)
-     (2 'develock-whitespace-face-3 nil t))
+     (1 'develock-whitespace-2)
+     (2 'develock-whitespace-3 nil t))
     ;; trailing whitespace
     ("[^\t\n ]\\([\t ]+\\)$"
-     (1 'develock-whitespace-face-1 t))
+     (1 'develock-whitespace-1 t))
     ;; spaces before tabs
     ("\\( +\\)\\(\t+\\)"
-     (1 'develock-whitespace-face-1 t)
-     (2 'develock-whitespace-face-2 t))
+     (1 'develock-whitespace-1 t)
+     (2 'develock-whitespace-2 t))
     ;; tab space tab
     ("\\(\t\\) \t"
-     (1 'develock-whitespace-face-2 append))
+     (1 'develock-whitespace-2 append))
     ;; only tabs or spaces in the line
     ("^[\t ]+$"
-     (0 'develock-whitespace-face-2 append))
+     (0 'develock-whitespace-2 append))
     ;; reachable E-mail addresses
     ("<?[-+.0-9A-Z_a-z]+@[-0-9A-Z_a-z]+\\(\\.[-0-9A-Z_a-z]+\\)+>?"
-     (0 'develock-reachable-mail-address-face t)))
+     (0 'develock-reachable-mail-address t)))
   "Extraordinary level highlighting for the Perl mode."
   :type develock-keywords-custom-type
   :set 'develock-keywords-custom-set
@@ -1067,28 +1105,28 @@ Each element should be triple symbols of the following form:
 (defcustom develock-mail-font-lock-keywords
   `(;; a long line
     (develock-find-long-lines
-     (1 'develock-long-line-face-1 t)
-     (2 'develock-long-line-face-2 t))
+     (1 'develock-long-line-1 t)
+     (2 'develock-long-line-2 t))
     ;; long spaces
     (develock-find-tab-or-long-space
-     (1 'develock-whitespace-face-2)
-     (2 'develock-whitespace-face-3 nil t))
+     (1 'develock-whitespace-2)
+     (2 'develock-whitespace-3 nil t))
     ;; trailing whitespace
     ("[^\t\n ]\\([\t ]+\\)$"
-     (1 'develock-whitespace-face-1 t))
+     (1 'develock-whitespace-1 t))
     ;; spaces before tabs
     ("\\( +\\)\\(\t+\\)"
-     (1 'develock-whitespace-face-1 t)
-     (2 'develock-whitespace-face-2 t))
+     (1 'develock-whitespace-1 t)
+     (2 'develock-whitespace-2 t))
     ;; tab space tab
     ("\\(\t\\) \t"
-     (1 'develock-whitespace-face-2 append))
+     (1 'develock-whitespace-2 append))
     ;; only tabs or spaces in the line
     ("^[\t ]+$"
-     (0 'develock-whitespace-face-2 append))
+     (0 'develock-whitespace-2 append))
     ,(if (featurep 'mule)
 	 ;; Japanese hankaku katakana
-	 '("\\ck+" (0 'develock-bad-manner-face t))))
+	 '("\\ck+" (0 'develock-bad-manner t))))
   "Extraordinary level highlighting for the Mail modes."
   :type develock-keywords-custom-type
   :set 'develock-keywords-custom-set
@@ -1098,28 +1136,28 @@ Each element should be triple symbols of the following form:
 (defcustom develock-tcl-font-lock-keywords
   '(;; a long line
     (develock-find-long-lines
-     (1 'develock-long-line-face-1 t)
-     (2 'develock-long-line-face-2 t))
+     (1 'develock-long-line-1 t)
+     (2 'develock-long-line-2 t))
     ;; long spaces
     (develock-find-tab-or-long-space
-     (1 'develock-whitespace-face-2)
-     (2 'develock-whitespace-face-3 nil t))
+     (1 'develock-whitespace-2)
+     (2 'develock-whitespace-3 nil t))
     ;; trailing whitespace
     ("[^\t\n ]\\([\t ]+\\)$"
-     (1 'develock-whitespace-face-1 t))
+     (1 'develock-whitespace-1 t))
     ;; spaces before tabs
     ("\\( +\\)\\(\t+\\)"
-     (1 'develock-whitespace-face-1 t)
-     (2 'develock-whitespace-face-2 t))
+     (1 'develock-whitespace-1 t)
+     (2 'develock-whitespace-2 t))
     ;; tab space tab
     ("\\(\t\\) \t"
-     (1 'develock-whitespace-face-2 append))
+     (1 'develock-whitespace-2 append))
     ;; only tabs or spaces in the line
     ("^[\t ]+$"
-     (0 'develock-whitespace-face-2 append))
+     (0 'develock-whitespace-2 append))
     ;; reachable E-mail addresses
     ("<?[-+.0-9A-Z_a-z]+@[-0-9A-Z_a-z]+\\(\\.[-0-9A-Z_a-z]+\\)+>?"
-     (0 'develock-reachable-mail-address-face t)))
+     (0 'develock-reachable-mail-address t)))
   "Extraordinary level highlighting for the Tcl mode."
   :type develock-keywords-custom-type
   :set 'develock-keywords-custom-set
@@ -1129,28 +1167,28 @@ Each element should be triple symbols of the following form:
 (defcustom develock-ruby-font-lock-keywords
   '(;; a long line
     (develock-find-long-lines
-     (1 'develock-long-line-face-1 t)
-     (2 'develock-long-line-face-2 t))
+     (1 'develock-long-line-1 t)
+     (2 'develock-long-line-2 t))
     ;; long spaces
     (develock-find-tab-or-long-space
-     (1 'develock-whitespace-face-2)
-     (2 'develock-whitespace-face-3 nil t))
+     (1 'develock-whitespace-2)
+     (2 'develock-whitespace-3 nil t))
     ;; trailing whitespace
     ("[^\t\n ]\\([\t ]+\\)$"
-     (1 'develock-whitespace-face-1 t))
+     (1 'develock-whitespace-1 t))
     ;; spaces before tabs
     ("\\( +\\)\\(\t+\\)"
-     (1 'develock-whitespace-face-1 t)
-     (2 'develock-whitespace-face-2 t))
+     (1 'develock-whitespace-1 t)
+     (2 'develock-whitespace-2 t))
     ;; tab space tab
     ("\\(\t\\) \t"
-     (1 'develock-whitespace-face-2 append))
+     (1 'develock-whitespace-2 append))
     ;; only tabs or spaces in the line
     ("^[\t ]+$"
-     (0 'develock-whitespace-face-2 append))
+     (0 'develock-whitespace-2 append))
     ;; reachable E-mail addresses
     ("<?[-+.0-9A-Z_a-z]+@[-0-9A-Z_a-z]+\\(\\.[-0-9A-Z_a-z]+\\)+>?"
-     (0 'develock-reachable-mail-address-face t)))
+     (0 'develock-reachable-mail-address t)))
   "Extraordinary level highlighting for the Ruby mode."
   :type develock-keywords-custom-type
   :set 'develock-keywords-custom-set
